@@ -611,12 +611,8 @@ _atspi_dbus_return_hyperlink_from_message (DBusMessage *message)
 {
   DBusMessageIter iter;
   AtspiHyperlink *retval = NULL;
-  const char *signature;
+  const char *signature = dbus_message_get_signature (message);
    
-  if (!message)
-    return NULL;
-
-  signature = dbus_message_get_signature (message);
   if (!strcmp (signature, "(so)"))
   {
     dbus_message_iter_init (message, &iter);
@@ -1462,3 +1458,32 @@ atspi_get_a11y_bus (void)
   
   return bus;
 }
+
+/**
+ *  Set the timeout used for method calls. If this is not set explicitly,
+ *  a default of 0.8 ms is used.
+ *  Note that at-spi2-registryd currently uses a timeout of 3 seconds when
+ *  sending a keyboard event notification. This means that, if an AT makes
+ *  a call in response to the keyboard notification and the application
+ *  being called does not respond before the timeout is reached,
+ *  at-spi2-registryd will time out on the keyboard event notification and
+ *  pass the key onto the application (ie, reply to indicate that the key
+ *  was not consumed), so this may make it undesirable to set a timeout
+ *  larger than 3 seconds.
+ *
+ *  @val: The timeout value, in milliseconds, or -1 to disable the timeout.
+ *  @startup_time: The amount of time, in milliseconds, to allow to pass
+ *  before enforcing timeouts on an application. Can be used to prevent
+ *  timeout exceptions if an application is likely to block for an extended
+ *  period of time on initialization. -1 can be passed to disable this
+ *  behavior.
+ *
+ * By default, the normal timeout is set to 800 ms, and the application startup
+ * timeout is set to 15 seconds.
+ */
+void
+atspi_set_timeout (gint val, gint startup_time)
+{
+  method_call_timeout = val;
+  app_startup_time = startup_time;
+}
